@@ -15,7 +15,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ikev1_quick.c,v 1.3.2.3 2006/04/04 22:17:49 paul Exp $
+ * RCSID $Id: ikev1_quick.c,v 1.3.2.7 2007-11-02 01:28:36 paul Exp $
  */
 
 #include <stdio.h>
@@ -545,17 +545,50 @@ check_net_id(struct isakmp_ipsec_id *id
 , const char *which)
 {
     ip_subnet net_temp;
+    bool bad_proposal=FALSE;
 
     if (!decode_net_id(id, id_pbs, &net_temp, which))
 	return FALSE;
 
-    if (!samesubnet(net, &net_temp)
-    || *protoid != id->isaiid_protoid || *port != id->isaiid_port)
-    {
-	loglog(RC_LOG_SERIOUS, "%s ID returned doesn't match my proposal", which);
-	return FALSE;
+    if (!samesubnet(net, &net_temp)) {
+	char subrec[SUBNETTOT_BUF];
+	char subxmt[SUBNETTOT_BUF];
+	subnettot(net, 0, subxmt, sizeof(subxmt));
+	subnettot(&net_temp, 0, subrec, sizeof(subrec));
+	loglog(RC_LOG_SERIOUS, "%s subnet returned doesn't match my proposal - us:%s vs them:%s",
+		which,subxmt,subrec);
+#ifdef ALLOW_MICROSOFT_BAD_PROPOSAL
+	loglog(RC_LOG_SERIOUS, "Allowing questionable proposal anyway [ALLOW_MICROSOFT_BAD_PROPOSAL]");
+	bad_proposal = FALSE;
+#else
+	bad_proposal = TRUE;
+#endif
     }
-    return TRUE;
+    if(*protoid != id->isaiid_protoid) {
+	loglog(RC_LOG_SERIOUS, "%s peer returned protocol id doesn't match my proposal - us%d vs them: %d",
+		 which,*protoid,id->isaiid_protoid);
+#ifdef ALLOW_MICROSOFT_BAD_PROPOSAL
+	loglog(RC_LOG_SERIOUS, "Allowing questionable proposal anyway [ALLOW_MICROSOFT_BAD_PROPOSAL]");
+	bad_proposal = FALSE;
+#else
+	bad_proposal = TRUE;
+#endif
+    }
+    /*
+     * workaround for #802- "our client ID returned doesn't match my proposal"
+     * until such time as bug #849 is properly fixed.
+     */
+    if (*port != id->isaiid_port) { 
+	loglog(RC_LOG_SERIOUS, "%s peer returned port doesn't match my proposal - us:%d vs them:%d",
+		which,*port,id->isaiid_port );
+	if (*port != 0 && id->isaiid_port!=1701) {
+		loglog(RC_LOG_SERIOUS, "Allowing bad L2TP/IPsec proposal (see bug #849) anyway");
+		bad_proposal = FALSE;
+	} else 
+		bad_proposal = TRUE;
+    }
+
+    return !bad_proposal;
 }
 
 
